aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorGravatar Jianwei Xie <xiejw@google.com>2017-04-11 14:05:42 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2017-04-11 15:26:01 -0700
commit43acf393020106400b7fc123d76aadea62a939dd (patch)
tree21d5f7941f141a4062eb010560e042994621a1eb
parent154b2169456cf61c630a58da4b90015a32562d1c (diff)
Update the docstring of tuner.
Change: 152866121
-rw-r--r--tensorflow/contrib/training/python/training/tuner.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tensorflow/contrib/training/python/training/tuner.py b/tensorflow/contrib/training/python/training/tuner.py
index b724c84c54..8843632619 100644
--- a/tensorflow/contrib/training/python/training/tuner.py
+++ b/tensorflow/contrib/training/python/training/tuner.py
@@ -29,11 +29,11 @@ class Tuner(object):
Example:
```
- def _create_my_experiment(config, hparams):
+ def _create_my_experiment(run_config, hparams):
hidden_units = [hparams.unit_per_layer] * hparams.num_hidden_layers
return tf.contrib.learn.Experiment(
- estimator=DNNClassifier(config=config, hidden_units=hidden_units),
+ estimator=DNNClassifier(config=run_config, hidden_units=hidden_units),
train_input_fn=my_train_input,
eval_input_fn=my_eval_input)
@@ -79,7 +79,7 @@ class Tuner(object):
Args:
experiment_fn: A function that creates an `Experiment`. It should accept
an argument `config` which should be used to create the `Estimator`
(passed as `config` to its constructor), and an argument `hparams`,
which should be used for hyper-parameters tuning. It must return an
`Experiment`.
@@ -79,7 +79,7 @@ class Tuner(object):
Args:
experiment_fn: A function that creates an `Experiment`. It should accept
- an argument `config` which should be used to create the `Estimator`
+ an argument `run_config` which should be used to create the `Estimator`
(passed as `config` to its constructor), and an argument `hparams`,
which should be used for hyper-parameters tuning. It must return an